<?php

namespace WPDesk\ShopMagic\Admin\SelectAjaxField;

use WPDesk\ShopMagic\FormField\BasicField;

/**
 * @TODO: remove static
 *
 * @package WPDesk\ShopMagic\Admin\SelectAjaxField
 */
class CustomerSelectAjax extends BasicField {
	/**
	 * @inheritDoc
	 */
	public function get_template_name() {
		return 'customer-select';
	}

	/**
	 * @return string
	 */
	public static function get_ajax_action_name() {
		return 'shopmagic_customer';
	}

	/**
	 * @internal
	 */
	public static function customer_select_ajax() {
		if ( ! isset( $_GET['term'] ) || ! current_user_can( 'manage_woocommerce' ) ) {
			die;
		}
		$term = sanitize_text_field( $_GET['term'] );

		$limit = 80;
		if ( 3 > strlen( $term ) ) {
			$limit = 20;
		}

		if ( empty( $term ) ) {
			wp_die();
		}

		$query = new \WP_User_Query(
			[
				'search'         => '*' . esc_attr( $term ) . '*',
				'search_columns' => [ 'user_login', 'user_email', 'user_nicename', 'display_name' ],
				'fields'         => 'ID',
				'number'         => $limit,
			]
		);

		$query2 = new \WP_User_Query(
			[
				'fields'     => 'ID',
				'number'     => $limit,
				'meta_query' => [
					'relation' => 'OR',
					[
						'key'     => 'first_name',
						'value'   => $term,
						'compare' => 'LIKE',
					],
					[
						'key'     => 'last_name',
						'value'   => $term,
						'compare' => 'LIKE',
					],
				],
			]
		);

		$user_ids = wp_parse_id_list( array_merge( $query->get_results(), $query2->get_results() ) );

		$results = [];
		foreach ( $user_ids as $customer_id ) {
			$customer = new \WP_User( $customer_id );
			$results[ $customer->ID ] = self::convert_value_to_option_text( $customer_id );
		}
		wp_send_json( $results );
	}

	/**
	 * @param int|\WP_User $value
	 *
	 * @return string
	 */
	public static function convert_value_to_option_text( $value ) {
		if ( $value instanceof \WP_User ) {
			$customer = $value;
		} else {
			$customer = new \WP_User( $value );
		}

		return sprintf(
			esc_html__( '%1$s &ndash; %2$s', 'shopmagic-for-woocommerce' ),
			"{$customer->first_name} {$customer->last_name}",
			$customer->user_email );
	}

	public static function hooks() {
		add_action( 'wp_ajax_' . self::get_ajax_action_name(), "\WPDesk\ShopMagic\Admin\SelectAjaxField\CustomerSelectAjax::customer_select_ajax" );
	}
}
