<?php

namespace WPDesk\ShopMagic\Admin\Settings;

use Psr\Container\ContainerInterface;
use ShopMagicVendor\WPDesk\Persistence\Adapter\ArrayContainer;
use WPDesk\ShopMagic\FormField\Field\CheckboxField;
use WPDesk\ShopMagic\FormField\Field\InputTextField;
use WPDesk\ShopMagic\FormField\Field\SubmitField;
use WPDesk\ShopMagic\Tracker\TrackerNotices;

final class GeneralSettings extends FieldSettingsTab {
	/**
	 * @inheritDoc
	 */
	protected function get_fields() {
		return [
			( new CheckboxField() )
				->set_label( __( 'Help Icon', 'shopmagic-for-woocommerce' ) )
				->set_sublabel( __( 'Disable help icon', 'shopmagic-for-woocommerce' ) )
				->set_description( __( 'Help icon shows only on ShopMagic pages with help articles and ability to ask for help. If you do not want the help icon to display, you can entirely disable it here.',
					'shopmagic-for-woocommerce' ) )
				->set_name( 'disable_beacon' ),

			( new CheckboxField() )
				->set_label( __( 'Usage Data', 'shopmagic-for-woocommerce' ) )
				->set_sublabel( __( 'Enable', 'shopmagic-for-woocommerce' ) )
				->set_description( sprintf( __( 'Help us improve ShopMagic and allow us to collect insensitive plugin usage data, %sread more%s.',
					'shopmagic-for-woocommerce' ), '<a href="' . TrackerNotices::USAGE_DATA_URL . '" target="_blank">',
					'</a>' ) )
				->set_name( 'wpdesk_tracker_agree' ),

			( new SubmitField() )
				->set_name( 'save' )
				->set_label( __( 'Save changes', 'shopmagic-for-woocommerce' ) )
				->add_class( 'button-primary' )
		];
	}

	/**
	 * @inheritDoc
	 */
	public static function get_tab_slug() {
		return 'general';
	}

	/**
	 * @inheritDoc
	 */
	public function get_tab_name() {
		return __( 'General', 'shopmagic-for-woocommerce' );
	}
}
