<?php

namespace WPDesk\ShopMagic\DataSharing;

/**
 * Provides test data. Uses last created order as \WC_Order
 *
 * @package WPDesk\ShopMagic\DataSharing
 */
class TestDataProvider implements DataProvider {
	/**
	 * @inheritDoc
	 */
	public function get_provided_data_domains() {
		if ( $this->can_provide_order() ) {
			$domains[] = \WC_Order::class;
			$domains[] = \WP_User::class;
			$domains[] = \WP_Post::class;
		}

		return apply_filters( 'shopmagic/core/test_data_provider/domains', $domains );
	}

	/**
	 * @return \WC_Order|null
	 */
	private function get_test_order() {
		$orders = wc_get_orders( [
			'limit'   => 1,
			'orderby' => 'date_created',
			'order'   => 'DESC'
		] );

		return reset( $orders );
	}

	/**
	 * If provider can really provide an order.
	 *
	 * @return bool
	 */
	public function can_provide_order() {
		return $this->get_test_order() instanceof \WC_Abstract_Order;
	}

	/**
	 * @inheritDoc
	 */
	public function get_provided_data() {
		$data = [];
		if ( $this->can_provide_order() ) {
			$test_order               = $this->get_test_order();
			$data[ \WC_Order::class ] = $test_order;
			$data[ \WP_User::class ]  = $test_order->get_user();
			$data[ \WP_Post::class ]  = $test_order;
		}

		return apply_filters( 'shopmagic/core/test_data_provider/data', $data );
	}
}
