<?php
namespace WPDesk\ShopMagic\Database;

trait RepositoryOrderTrait {
	/**
	 * @param array $order Order clauses in format [ field => asc/desc, field2 => asc/desc ]
	 * OR in format [ [ 'field' => .., 'condition' => .., 'value' => ...], ... ]
	 *
	 * @return string
	 */
	private function order_array_to_sql( array $order ) {
		if ( empty( $order ) ) {
			return '';
		}
		$order_clauses = [];
		foreach ( $order as $key => $val ) {
			$order_clauses[] = "{$key} {$val}";
		}

		return ' ORDER BY ' . implode( ',', $order_clauses );
	}

	private function limit_offset_to_sql( $limit, $offset ) {
		return " LIMIT {$limit} OFFSET {$offset}";
	}

	/**
	 * @param array $where
	 *
	 * @return string
	 */
	private function where_array_to_sql( array $where ) {
		if ( empty( $where ) ) {
			return ' 1 = 1 ';
		}
		$where_clauses = [];
		$where_values  = [];
		foreach ( $where as $key => $val ) {
			if ( is_array( $val ) ) {
				$where_clauses[] = "{$val['field']} {$val['condition']} %s";
				$where_values[]  = $val['value'];
			} else {
				$where_clauses[] = "{$key} = %s";
				$where_values[]  = $val;
			}
		}

		return $this->wpdb->prepare( ' ' . implode( ' AND ', $where_clauses ), $where_values );
	}
}
