<?php

namespace WPDesk\ShopMagic\Filter;


use WPDesk\ShopMagic\DataSharing\DataProvider;
use WPDesk\ShopMagic\DataSharing\DataReceiver;
use WPDesk\ShopMagic\DataSharing\ProviderReceiverMatcher;
use WPDesk\ShopMagic\Filter\Builtin\Customer\CustomerListFilter;
use WPDesk\ShopMagic\Filter\Builtin\Customer\CustomerEmail;
use WPDesk\ShopMagic\Filter\Builtin\Customer\CustomerIsGuest;
use WPDesk\ShopMagic\Filter\Builtin\Customer\CustomerMeta;
use WPDesk\ShopMagic\Filter\Builtin\Customer\CustomerTotalSpent;
use WPDesk\ShopMagic\Filter\Builtin\Order\OrderCreatedDate;
use WPDesk\ShopMagic\Filter\Builtin\Order\OrderItemCategories;
use WPDesk\ShopMagic\Filter\Builtin\Order\OrderMeta;
use WPDesk\ShopMagic\Filter\Builtin\Order\OrderPaidDate;
use WPDesk\ShopMagic\Filter\Builtin\Order\OrderItems;
use WPDesk\ShopMagic\Filter\Builtin\Order\OrderPaymentGateway;
use WPDesk\ShopMagic\Filter\Builtin\Order\OrderShippingMethod;
use WPDesk\ShopMagic\Filter\Builtin\Order\OrderTotal;

final class FilterFactory {

	/**
	 * @return Filter[]
	 */
	public function get_filter_list() {
		return apply_filters( 'shopmagic/core/filters', $this->get_build_in_filters() );
	}

	/**
	 * @param string $slug
	 *
	 * @return Filter
	 */
	public function create_filter( $slug ) {
		return clone $this->get_filter( $slug );
	}

	/**
	 * @param DataProvider $provider
	 *
	 * @return DataReceiver[]|Filter[]
	 */
	public function get_filter_list_to_handle( DataProvider $provider ) {
		$list = ProviderReceiverMatcher::matchReceivers( $provider, $this->get_filter_list() );
		uasort( $list, function ( Filter $a, Filter $b ) {
			$group_compare = strcmp( $a->get_group_slug(), $b->get_group_slug() );
			if ( $group_compare === 0 ) {
				return strcmp( $a->get_name(), $b->get_name() );
			}

			return $group_compare;
		} );

		return $list;
	}

	/**
	 * @param string
	 *
	 * @return Filter
	 */
	public function get_filter( $slug ) {
		$filters = $this->get_filter_list();
		if ( isset( $filters[ $slug ] ) ) {
			return apply_filters( 'shopmagic/core/single_filter', $filters[ $slug ] );
		}

		return new NullFilter();
	}

	/**
	 * @return Filter[]
	 */
	private function get_build_in_filters() {
		return array(
			'shopmagic_product_purchased_filter' => new OrderItems(), // warning - legacy key
			'customer_communication_type'        => new CustomerListFilter()
		);
	}
}
