<?php


namespace WPDesk\ShopMagic\Helper;

/**
 * Idea behind this helper is to facilitate various formatting methods that depends on WordPress.
 *
 * Access should be static to lower complexity. It can be refactored in the future when DI container is introduced.
 *
 * @package WPDesk\ShopMagic\Helper
 */
final class WordPressFormatHelper {
	/**
	 * @param string|\WC_DateTime|\DateTimeInterface|int|null $date
	 *
	 * @return string
	 */
	public static function format_wp_date( $date ) {
		$utc_stamp = self::convert_all_time_to_utc_stamp( $date );
		if ( $utc_stamp === false ) {
			return '';
		}

		$wp_date_format = get_option( 'date_format', 'Y-m-d' );

		return ( new \DateTimeImmutable( 'now', wp_timezone() ) )
			->setTimestamp( $utc_stamp )
			->format( $wp_date_format );
	}

	/**
	 * @param string|\WC_DateTime|\DateTimeInterface|int|null $datetime
	 *
	 * @return int|false
	 */
	private static function convert_all_time_to_utc_stamp( $datetime ) {
		if ( is_numeric( $datetime ) ) {
			return (int) $datetime;
		}

		if ( is_string( $datetime ) ) {
			return strtotime( $datetime );
		}

		if ( $datetime instanceof \DateTimeInterface ) {
			return (int) $datetime->getTimestamp() - $datetime->getOffset();
		}

		return false;
	}

	/**
	 * @param string|\WC_DateTime|\DateTimeInterface|int|null $datetime
	 *
	 * @param string $datetime_format
	 *
	 * @return string
	 */
	public static function format_wp_datetime( $datetime, $datetime_format = '' ) {
		$utc_stamp = self::convert_all_time_to_utc_stamp( $datetime );
		if ( $utc_stamp === false ) {
			return '';
		}

		if ( empty( $datetime_format ) ) {
			$wp_date_format  = get_option( 'date_format', 'Y-m-d' );
			$wp_time_format  = get_option( 'time_format', 'G:i:s' );
			$datetime_format = "$wp_date_format $wp_time_format";
		}

		return ( new \DateTimeImmutable( 'now', wp_timezone() ) )
			->setTimestamp( $utc_stamp )
			->format( $datetime_format );
	}

	/**
	 * @param string|\WC_DateTime|\DateTimeInterface|int|null $datetime
	 *
	 * @return string
	 */
	public static function format_wp_datetime_with_seconds( $datetime ) {
		$utc_stamp = self::convert_all_time_to_utc_stamp( $datetime );
		if ( $utc_stamp === false ) {
			return '';
		}

		$wp_date_format  = get_option( 'date_format', 'Y-m-d' );
		$wp_time_format  = get_option( 'time_format', 'G:i' );
		$datetime_format = "$wp_date_format {$wp_time_format}:s";

		return ( new \DateTimeImmutable( 'now', wp_timezone() ) )
			->setTimestamp( $utc_stamp )
			->format( $datetime_format );
	}
}
